<?php
require PDF_PLUGIN_DIR . 'vendor/autoload.php';
use Dompdf\Dompdf;
use Dompdf\Options;
use Dompdf\FontMetrics;

if (!defined('ABSPATH'))
{
	exit;
}
class AF_P_D_F_I_Admin
{

	public function __construct()
	{
		add_action('all_admin_notices', array($this, 'invoices_display_tabs'), 5);
		add_action('admin_menu', array($this, 'addify_invoices_submenu'));
		add_action('admin_init', array($this, 'invoices_pdf_regester_general_setting'));
		add_action('admin_enqueue_scripts', array($this, 'addify_invoices_fields_style'));
		add_action('woocommerce_email_attachments', array($this, 'af_pdf_invoice_to_order_email'), 10, 3);
		add_action('manage_woocommerce_page_wc-orders_custom_column', array($this, 'source_medium_value'), 10, 2);
		add_action('wp_ajax_download_invoice_pdf', array($this, 'addify_handle_download_invoice_pdf'));
		add_action('wp_ajax_download_packing_slip_pdf', array($this, 'addify_handle_download_packing_slip_pdf'));
		add_filter('bulk_actions-woocommerce_page_wc-orders', array($this, 'addify_invoice_pdf_bulk_action'));
		add_filter('handle_bulk_actions-woocommerce_page_wc-orders', array($this, 'addify_handle_bulk_actions'), 10, 3);
		add_action('admin_init', array($this, 'addify_bulk_download_invoices_action'));
		add_action('wp_ajax_af_invoices_pdf_preview', array($this, 'af_invoices_pdf_preview'));
		add_action('add_meta_boxes', array($this, 'af_pdf_invoices_adding_meta'));
		add_action('woocommerce_email_attachments', array($this, 'attach_credit_note_to_refund_order_email'), 10, 3);
		add_action('wp_ajax_download_credit_note_pdf', [$this, 'download_credit_note_pdf']);
		add_action('wp_ajax_nopriv_download_credit_note_pdf', [$this, 'download_credit_note_pdf']);


	}
	public function download_credit_note_pdf()
	{
		if (!isset($_GET['order_id']) || !wp_verify_nonce($_GET['_wpnonce'], 'download_credit_note_pdf'))
		{
			wp_die(__('Invalid request', 'af_pdf_invoices'));
		}

		$order_id = intval($_GET['order_id']);
		$this->addify_generate_and_download_credit_note([$order_id]);
		exit;
	}

	public function addify_generate_and_download_credit_note($order_ids_array)
	{
		$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/credit-note';
		$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/credit-note';
		$default_design = 'credit_note_temp1.php';

		if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir))
		{
			$base_dir = $default_base_dir;
		}
		else
		{
			$base_dir = $custom_base_dir;
		}

		$af_pdf_invoices_credit_note_design = get_option('af_pdf_invoices_credit_note_design');

		if (!$af_pdf_invoices_credit_note_design)
		{
			$af_pdf_invoices_credit_note_design = $default_design;
		}
		else
		{
			if (substr($af_pdf_invoices_credit_note_design, -4) !== '.php')
			{
				$af_pdf_invoices_credit_note_design .= '.php';
			}

			if (!file_exists($base_dir . '/' . $af_pdf_invoices_credit_note_design))
			{
				if (file_exists($default_base_dir . '/' . $af_pdf_invoices_credit_note_design))
				{
					$base_dir = $default_base_dir;
				}
				else
				{
					$af_pdf_invoices_credit_note_design = $default_design;
					$base_dir = $default_base_dir;
				}
			}
		}

		foreach ((array)$order_ids_array as $order_id)
		{
			$order = wc_get_order($order_id);
			if (!$order)
			{
				continue;
			}

			$file_to_include = $base_dir . '/' . $af_pdf_invoices_credit_note_design;

			ob_start();
			include $file_to_include;
			$af_invoice_credit_note = ob_get_clean();

			$options = new Options();
			$options->set('isPhpEnabled', 'true');
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_credit_note);
			$dompdf->setPaper('A4', 'Portrait');
			$dompdf->render();
			$dompdf->stream('credit-note-' . $order_id . '.pdf', array("Attachment" => 1));
		}
	}

	public function attach_credit_note_to_refund_order_email($attachments, $email_id, $order)
	{

		// $af_pdf_invoices_credit_note_option = get_option('af_pdf_invoices_credit_note_option');

		// if ($af_pdf_invoices_credit_note_option) {

		// }

		if ($email_id == 'customer_refunded_order')
		{
			$af_pdf_invoices_credit_note_design = get_option('af_pdf_invoices_credit_note_design') ? get_option('af_pdf_invoices_credit_note_design') : 'credit_note_temp1';
			$base_dir = PDF_PLUGIN_DIR . 'includes/templates/credit-note';
			$template_path = $base_dir . '/' . $af_pdf_invoices_credit_note_design;

			if (!file_exists($template_path))
			{
				error_log("Template file not found: " . $template_path);
				return $attachments;
			}
			ob_start();
			include $template_path;
			$af_credit_note = ob_get_clean();

			error_log("Credit Note HTML: " . $af_credit_note);

			require PDF_PLUGIN_DIR . 'vendor/autoload.php';

			$options = new \Dompdf\Options();
			$options->set('isPhpEnabled', true);
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new \Dompdf\Dompdf($options);
			$dompdf->loadHtml($af_credit_note);

			error_log("HTML loaded into Dompdf");

			$dompdf->setPaper('A4', 'portrait');
			$dompdf->render();

			$output = $dompdf->output();
			$basedir = wp_upload_dir()['basedir'];
			$directory = $basedir . '/addify-pdf-invoices/';
			wp_mkdir_p($directory);
			$pdf_path = $directory . 'invoice-' . $order->get_id() . '.pdf';

			if (file_exists($pdf_path))
			{
				unlink($pdf_path);
			}

			file_put_contents($pdf_path, $output);

			error_log("PDF created at: " . $pdf_path);

			$attachments[] = $pdf_path;
		}

		return $attachments;
	}


	public function af_pdf_invoices_adding_meta()
	{
		$current_screen = get_current_screen();

		if ('woocommerce_page_wc-orders' === $current_screen->id || 'shop_order' === $current_screen->id)
		{
			add_meta_box(
			 'af_pdf_invoices',
			 esc_html__('Addify PDF Invoices', 'custom-messages'),
			 array($this, 'af_pdf_invoices_order_pdf'),
			 $current_screen->id,
			 'side',
			 'default'
			);
		}
	}
	public function af_pdf_invoices_order_pdf($post)
	{
		$order = wc_get_order($post->ID);
		if ($order)
		{
			$order_id = $order->get_id();
			$order_status = $order->get_status();

			if ($order_status === 'refunded')
			{
				$download_credit_note_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_credit_note_pdf&order_id=' . $order_id), 'download_credit_note_pdf');
				echo '<a href="' . esc_url($download_credit_note_url) . '" class="button" style="background-color: blue; color: white; margin-top: 10px;"><i class="fa fa-download" aria-hidden="true"></i> ' . esc_html__('Download Credit Note', 'af_pdf_invoices') . '</a>';
			}
			else
			{
				$download_invoice_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_invoice_pdf&order_id=' . $order_id), 'download_invoice_pdf');
				echo '<a href="' . esc_url($download_invoice_url) . '" class="button" style="background-color: blue; color: white; margin-top: 10px;"><i class="fa fa-download" aria-hidden="true"></i> ' . esc_html__('Download PDF', 'af_pdf_invoices') . '</a>';
				$download_packing_slip_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_packing_slip_pdf&order_id=' . $order_id), 'download_packing_slip_pdf');
				echo '<a href="' . esc_url($download_packing_slip_url) . '" class="button" style="background-color: blue; color: white; margin-top: 10px;"><i class="fa fa-download" aria-hidden="true"></i> ' . esc_html__('Download Packing Slip', 'af_pdf_invoices') . '</a>';
			}
		}
	}

	public function af_invoices_pdf_preview()
	{
		parse_str(sanitize_text_field($_POST['form_data']), $form_data);
		$header_logo = $_POST['header_logo'] ?? '';

		$template_functions = [
		 'temp1.php' => 'af_pdf_invoices_temp1',
		 'temp2.php' => 'af_pdf_invoices_temp2',
		 'temp3.php' => 'af_pdf_invoices_temp3',
		];

		ob_start();
		if (isset($template_functions[$form_data['af_invoice_pdf_select_design']]))
		{
			call_user_func($template_functions[$form_data['af_invoice_pdf_select_design']], $form_data, $header_logo);
		}
		$af_invoice_pdf = ob_get_clean();

		require PDF_PLUGIN_DIR . 'vendor/autoload.php';

		$options = new Options();
		$options->set('isPhpEnabled', true);
		$options->set('isRemoteEnabled', true);
		$options->set('defaultPaperSize', 'letter');
		$options->set('isHtml5ParserEnabled', true);

		$dompdf = new Dompdf($options);
		$dompdf->loadHtml($af_invoice_pdf);
		$dompdf->setPaper('A4', 'portrait');
		$dompdf->render();

		$pdf_output = $dompdf->output();

		wp_send_json([
		 'template' => $af_invoice_pdf,
		 'pdf_data' => base64_encode($pdf_output)
		]);
		wp_die();
	}




	function addify_generate_and_download_zip_invoices($order_ids)
	{
		$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
		$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
		$default_design = 'temp1.php';
		if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir))
		{
			$base_dir = $default_base_dir;
		}
		else
		{
			$base_dir = $custom_base_dir;
		}
		$zip = new ZipArchive();
		$zip_filename = tempnam(sys_get_temp_dir(), 'invoices') . '.zip';

		if ($zip->open($zip_filename, ZipArchive::CREATE) !== TRUE)
		{
			exit("Cannot open <$zip_filename>\n");
		}
		foreach ($order_ids as $order_id)
		{
			$order = wc_get_order($order_id);
			if (!$order)
			{
				continue;
			}
			$af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design');
			if (!$af_invoice_pdf_select_design)
			{
				$af_invoice_pdf_select_design = $default_design;
			}
			else
			{
				if (substr($af_invoice_pdf_select_design, -4) !== '.php')
				{
					$af_invoice_pdf_select_design .= '.php';
				}
				if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design))
				{

					if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design))
					{
						$base_dir = $default_base_dir;
					}
					else
					{
						$af_invoice_pdf_select_design = $default_design;
						$base_dir = $default_base_dir;
					}
				}
			}
			$file_to_include = $base_dir . '/' . $af_invoice_pdf_select_design;
			ob_start();
			include $file_to_include;
			$af_invoice_pdf = ob_get_clean();

			$options = new Options();
			$options->set('isPhpEnabled', true);
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_pdf);
			$dompdf->setPaper('A4', 'portrait');
			$dompdf->render();

			$pdf_output = $dompdf->output();
			$zip->addFromString('invoice-' . $order_id . '.pdf', $pdf_output);
		}

		$zip->close();

		header('Content-Type: application/zip');
		header('Content-disposition: attachment; filename=invoices.zip');
		header('Content-Length: ' . filesize($zip_filename));
		readfile($zip_filename);
		unlink($zip_filename);
		exit;
	}

	function addify_bulk_download_invoices_action()
	{
		if (!isset($_GET['bulk_download_invoices'], $_GET['order_ids'], $_GET['_wpnonce']))
		{
			return;
		}

		if (!wp_verify_nonce($_GET['_wpnonce'], 'bulk_download_invoices'))
		{
			return;
		}

		$order_ids = explode(',', $_GET['order_ids']);
		if (empty($order_ids))
		{
			return;
		}

		$this->addify_generate_and_download_zip_invoices($order_ids);
		exit;
	}
	public function addify_handle_bulk_actions($redirect_to, $do_action, $post_ids)
	{
		if ($do_action === 'download_pdfs')
		{
			if (!empty($post_ids))
			{
				$nonce = wp_create_nonce('bulk_download_invoices');
				$order_ids = implode(',', $post_ids);
				$redirect_to = add_query_arg(array(
				 'bulk_download_invoices' => 1,
				 'order_ids' => $order_ids,
				 '_wpnonce' => $nonce
				), $redirect_to);
			}
		}
		return $redirect_to;
	}
	public function addify_invoice_pdf_bulk_action($bulk_actions)
	{
		$bulk_actions['download_pdfs'] = ' Addify download PDF invoices';
		return $bulk_actions;
	}

	public function source_medium_value($column, $order)
	{

		if ($column == 'wc_actions')
		{
			$download_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_invoice_pdf&order_id=' . $order->get_id()), 'download_invoice_pdf');
			echo '<a href="' . esc_url($download_url) . '"><i class="fa fa-download" aria-hidden="true"></i></a>';
		}
	}

	function addify_handle_download_packing_slip_pdf()
	{
		$order_id = intval($_GET['order_id']);
		$this->addify_generate_and_download_packing_slip([$order_id]);
		exit;
	}
	function addify_handle_download_invoice_pdf()
	{
		$order_id = intval($_GET['order_id']);
		$this->addify_generate_and_download_pdf_invoice([$order_id]);
		exit;
	}
	function addify_generate_and_download_pdf_invoice($order_ids_array)
	{
		$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
		$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
		$default_design = 'temp1.php';


		if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir))
		{
			$base_dir = $default_base_dir;
		}
		else
		{
			$base_dir = $custom_base_dir;
		}

		$af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design');

		if (!$af_invoice_pdf_select_design)
		{
			$af_invoice_pdf_select_design = $default_design;
		}
		else
		{
			if (substr($af_invoice_pdf_select_design, -4) !== '.php')
			{
				$af_invoice_pdf_select_design .= '.php';
			}

			if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design))
			{

				if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design))
				{
					$base_dir = $default_base_dir;
				}
				else
				{
					$af_invoice_pdf_select_design = $default_design;
					$base_dir = $default_base_dir;
				}
			}
		}


		foreach ((array)$order_ids_array as $order_id)
		{
			$order = wc_get_order($order_id);
			if (!$order)
			{
				continue;
			}

			$file_to_include = $base_dir . '/' . $af_invoice_pdf_select_design;


			ob_start();
			include $file_to_include;
			$af_invoice_pdf = ob_get_clean();

			$options = new Options();
			$options->set('isPhpEnabled', 'true');
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_pdf);
			$dompdf->setPaper('A4', 'Portrait');
			$dompdf->render();
			$dompdf->stream('invoice-' . $order_id . '.pdf', array("Attachment" => 1));
		}
	}



	function addify_generate_and_download_packing_slip($order_ids_array)
	{
		$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/packing-slip';
		$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/packing-slip';
		$default_design = 'packing_slip_temp1.php';


		if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir))
		{

			$base_dir = $default_base_dir;
		}
		else
		{
			$base_dir = $custom_base_dir;
		}


		$af_pdf_invoices_packing_slip_design = get_option('af_pdf_invoices_packing_slip_design');


		if (!$af_pdf_invoices_packing_slip_design)
		{
			$af_pdf_invoices_packing_slip_design = $default_design;
		}
		else
		{

			if (substr($af_pdf_invoices_packing_slip_design, -4) !== '.php')
			{
				$af_pdf_invoices_packing_slip_design .= '.php';
			}


			if (!file_exists($base_dir . '/' . $af_pdf_invoices_packing_slip_design))
			{



				if (file_exists($default_base_dir . '/' . $af_pdf_invoices_packing_slip_design))
				{

					$base_dir = $default_base_dir;
				}
				else
				{

					$af_pdf_invoices_packing_slip_design = $default_design;
					$base_dir = $default_base_dir;
				}
			}
		}



		foreach ((array)$order_ids_array as $order_id)
		{
			$order = wc_get_order($order_id);
			if (!$order)
			{
				continue;
			}

			$file_to_include = $base_dir . '/' . $af_pdf_invoices_packing_slip_design;



			ob_start();
			include $file_to_include;
			$af_invoice_packing_slip = ob_get_clean();

			$options = new Options();
			$options->set('isPhpEnabled', 'true');
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_packing_slip);
			$dompdf->setPaper('A4', 'Portrait');
			$dompdf->render();
			$dompdf->stream('packing-slip-' . $order_id . '.pdf', array("Attachment" => 1));
		}
	}





	public function af_pdf_invoice_to_order_email($attachments, $email_id, $order)
	{
		$af_invoices_pdf_select_email = (array)get_option('af_invoices_pdf_select_email');
		$af_pdf_invoices_email = array_map('strtolower', $af_invoices_pdf_select_email);
		if (in_array(strtolower('wc_email_' . $email_id), $af_pdf_invoices_email))
		{

			$custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
			$default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
			$default_design = 'temp1.php';
			if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir))
			{
				$base_dir = $default_base_dir;
			}
			else
			{
				$base_dir = $custom_base_dir;
			}
			$af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design') ? get_option('af_invoice_pdf_select_design') : $default_design;
			if (substr($af_invoice_pdf_select_design, -4) !== '.php')
			{
				$af_invoice_pdf_select_design .= '.php';
			}
			if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design))
			{
				if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design))
				{
					$base_dir = $default_base_dir;
				}
				else
				{
					$af_invoice_pdf_select_design = $default_design;
					$base_dir = $default_base_dir;
				}
			}

			ob_start();
			include $base_dir . '/' . $af_invoice_pdf_select_design;
			$af_invoice_pdf = ob_get_clean();

			require PDF_PLUGIN_DIR . 'vendor/autoload.php';

			$options = new Options();
			$options->set('isPhpEnabled', true);
			$options->set('isRemoteEnabled', true);
			$options->set('defaultPaperSize', 'letter');
			$options->set('isHtml5ParserEnabled', true);

			$dompdf = new Dompdf($options);
			$dompdf->loadHtml($af_invoice_pdf);
			$dompdf->setPaper('A4', 'Portrait');
			$dompdf->render();

			$output = $dompdf->output();
			$basedir = wp_upload_dir()['basedir'];
			$directory = $basedir . '/addify-pdf-invoices/';
			wp_mkdir_p($directory);
			$pdf_path = $directory . 'invoice-' . $order->get_id() . '.pdf';

			if (file_exists($pdf_path))
			{
				unlink($pdf_path);
			}
			file_put_contents($pdf_path, $output);
			$attachments[] = $pdf_path;

		}

		return $attachments;
	}


	public function addify_invoices_fields_style()
	{

		wp_enqueue_media();

		wp_enqueue_style('select2-css', plugins_url('assets/css/select2.css', WC_PLUGIN_FILE), array(), '5.7.2');

		wp_enqueue_style('msc-admin-css', PDFI_URL . '/includes/assest/css/admin.css', false, '1.1.0');


		wp_enqueue_script('select2-js', plugins_url('assets/js/select2/select2.min.js', WC_PLUGIN_FILE), array('jquery'), '4.0.3', true);



		wp_enqueue_script('pdf_admin', PDFI_URL . 'includes/assest/js/admin.js', false, '1.0.0');
		wp_enqueue_style('af_mli_font_awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', false, '4.7.0', false);

		$aurgs = [
		 'admin_url' => admin_url('admin-ajax.php'),
		 'temp1.php' => af_pdf_invoices_temp1(),
		 'temp2.php' => af_pdf_invoices_temp2(),
		 'temp3.php' => af_pdf_invoices_temp3(),
		];

		wp_localize_script('pdf_admin', 'af_pdf_invoice', $aurgs);

	}

	public function invoices_pdf_regester_general_setting()
	{

		include PDF_PLUGIN_DIR . 'includes/settings/class_af_p_d_f_general.php';
		include PDF_PLUGIN_DIR . 'includes/settings/credit_note_setting.php';
		include PDF_PLUGIN_DIR . 'includes/settings/packing_slip_setting.php';
	}



	public function addify_invoices_submenu()
	{
		add_submenu_page(
		 'woocommerce',
		 'WooCommerce invoices Settings',
		 'invoices Settings',
		 'manage_options',
		 'invoices-settings',
		 array($this, 'invoices_render_custom_submenu') // callback

		);



	}
	function invoices_render_custom_submenu()
	{
		$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'general';
		$section = isset($_GET['section']) ? sanitize_text_field($_GET['section']) : 'layout';

		?>
		<div class="wrap">


			<form method="post" action="options.php">
				<?php

				switch ($active_tab)
				{
					case 'general':
						?>
						<ul class="subsubsub" style="margin: 0 !important;">
							<li>
								<a class="<?php echo 'layout' === $section ? 'current' : ''; ?>"
									href="<?php echo esc_url(admin_url('admin.php?page=invoices-settings&section=layout')); ?>">Layout</a>
							</li>
							|
							<li>
								<a class="<?php echo 'data-settings' === $section ? 'current' : ''; ?>"
									href="<?php echo esc_url(admin_url('admin.php?page=invoices-settings&section=data-settings')); ?>">Data
									Settings</a>
							</li>
						</ul>
						<?php
						if ('layout' === $section)
						{
							settings_fields('addify_invoices_pdf_general_settings_fields');
							do_settings_sections('addify_invoices_pdf_general_settings_sections');
							submit_button();
						}
						elseif ('data-settings' === $section)
						{
							settings_fields('addify_invoices_pdf_data_settings_fields');
							do_settings_sections('addify_invoices_pdf_data_settings_sections');
							submit_button();
						}
						break;
					case 'credit_note_setting':
						settings_fields('addify_invoices_pdf_credit_note_fields');
						do_settings_sections('addify_invoices_pdf_credit_note_sections');
						submit_button();
						break;


					case 'packing_slip_setting':
						settings_fields('addify_invoices_pdf_packing_slip_fields');
						do_settings_sections('addify_invoices_pdf_packing_slip_sections');
						submit_button();
						break;

				}
				?>
			</form>
		</div>
		<?php
	}







	public function invoices_display_tabs()
	{
		global $post, $typenow;
		$screen = get_current_screen();
		if ($screen && in_array($screen->id, $this->invoices_get_tab_screen_ids(), true))
		{
			// List of your tabs.
			$tabs = array(

			 'general_setting' => array(
			  'title' => __('Pdf invoices settings', 'invoices_for_woo'),
			  'url' => admin_url('admin.php?page=invoices-settings'),
			 ),
			 'credit_note_setting' => array(
			  'title' => __('Credit notes settings', 'invoices_for_woo'),
			  'url' => admin_url('admin.php?page=invoices-settings&tab=credit_note_setting'),
			 ),

			 'packing_slip_setting' => array(
			  'title' => __('Packing slip settings', 'invoices_for_woo'),
			  'url' => admin_url('admin.php?page=invoices-settings&tab=packing_slip_setting'),
			 ),


			// 'auction_page'        => array(
			// 	'title' => __('Auction Page', 'invoices_for_woo'), 
			// 	'url'   => admin_url('admin.php?page=invoices-settings&tab=auction_page'), 
			// ),
			// 'customization'        => array(
			// 	'title' => __('Customization Page', 'invoices_for_woo'), 
			// 	'url'   => admin_url('admin.php?page=invoices-settings&tab=customization'), 
			// ),

			// 'invoices_for_user'        => array(
			// 	'title' => __('Users Bids', 'invoices_for_woo'), 
			// 	'url'   => admin_url('edit.php?post_type=invoices_for_user'), 
			// ),


			);

			if (is_array($tabs))
			{ ?>
				<div class="wrap woocommerce">
					<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">
						<?php
						$current_tab = $this->invoices_get_current_tab();
						foreach ($tabs as $id => $tab_data)
						{
							$class = $id === $current_tab ? array('nav-tab', 'nav-tab-active') : array('nav-tab');
							printf('<a href="%1$s" class="%2$s">%3$s</a>', esc_url($tab_data['url']), implode(' ', array_map('sanitize_html_class', $class)), esc_html($tab_data['title']));
						}
						?>
					</h2>
				</div>
				<?php
			}
		}
	}
	public function invoices_get_tab_screen_ids()
	{
		$tabs_screens = array(
		 'city_invoices_for_woo',
		 'edit-city_invoices_for_woo',
		 'pages',
		 'edit-pages',
		 'invoices_for_user',
		 'edit-invoices_for_user',
		 'woocommerce_page_invoices-settings',
		);
		return $tabs_screens;
	}


	public function invoices_get_current_tab()
	{
		$screen = get_current_screen();
		$screen_id = $screen->id;

		if ('woocommerce_page_invoices-settings' == $screen_id)
		{
			$screen_id = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'general';
		}

		switch ($screen_id)
		{

			case 'general':
				return 'general_setting';
			case 'credit_note_setting':
				return 'credit_note_setting';
			case 'packing_slip_setting':
				return 'packing_slip_setting';




		}
	}


}
if (class_exists('AF_P_D_F_I_Admin'))
{
	new AF_P_D_F_I_Admin();
}