<?php
if (!defined('WPINC'))
{
    die;
}
class Addify_P_D_F_I_Front
{

    public function __construct()
    {


        add_action('wp_enqueue_scripts', array($this, 'af_pdf_invoices_front_assests'), 10);
        
         add_filter('woocommerce_account_orders_columns', array($this, 'add_pdf_download_column'), 10, 2);
        add_action('woocommerce_my_account_my_orders_column_pdf-download', array($this, 'populate_pdf_download_column'), 10, 1);
        add_action('wp_ajax_download_invoice_pdf', array($this, 'handle_download_invoice_pdf'));
        add_action('wp_ajax_nopriv_download_invoice_pdf', array($this, 'handle_download_invoice_pdf'));
        add_action('wp_ajax_download_credit_note_pdf', array($this, 'handle_download_credit_note_pdf'));
        add_action('wp_ajax_nopriv_download_credit_note_pdf', array($this, 'handle_download_credit_note_pdf'));

    }

   public function handle_download_invoice_pdf() {
        if (!isset($_GET['order_id']) || !wp_verify_nonce($_REQUEST['_wpnonce'], 'download_invoice_pdf')) {
            die('Invalid request');
        }

        $order_id = intval($_GET['order_id']);
        $this->generate_and_download_pdf_invoice($order_id);
        exit;
    }

    public function generate_and_download_pdf_invoice($order_id) {
        $order = wc_get_order($order_id);
        if (!$order) {
            return;
        }

        $custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/pdf-invoices';
        $default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/pdf';
        $default_design = 'temp1.php';

        if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir)) {
            $base_dir = $default_base_dir;
        } else {
            $base_dir = $custom_base_dir;
        }

        $af_invoice_pdf_select_design = get_option('af_invoice_pdf_select_design') ? get_option('af_invoice_pdf_select_design') : $default_design;

        if (substr($af_invoice_pdf_select_design, -4) !== '.php') {
            $af_invoice_pdf_select_design .= '.php';
        }

        if (!file_exists($base_dir . '/' . $af_invoice_pdf_select_design)) {
            if (file_exists($default_base_dir . '/' . $af_invoice_pdf_select_design)) {
                $base_dir = $default_base_dir;
            } else {
                $af_invoice_pdf_select_design = $default_design;
                $base_dir = $default_base_dir;
            }
        }

        ob_start();
        include $base_dir . '/' . $af_invoice_pdf_select_design;
        $af_invoice_pdf = ob_get_clean();

        $options = new Dompdf\Options();
        $options->set('isPhpEnabled', true);
        $options->set('isRemoteEnabled', true);
        $options->set('defaultPaperSize', 'letter');
        $options->set('isHtml5ParserEnabled', true);
        $dompdf = new Dompdf\Dompdf($options);
        $dompdf->loadHtml($af_invoice_pdf);
        $dompdf->setPaper('A4', 'Portrait');
        $dompdf->render();
        $dompdf->stream('invoice-' . $order_id . '.pdf', array("Attachment" => 1));
    }

    public function handle_download_credit_note_pdf() {
        if (!isset($_GET['order_id']) || !wp_verify_nonce($_REQUEST['_wpnonce'], 'download_credit_note_pdf')) {
            die('Invalid request');
        }

        $order_id = intval($_GET['order_id']);
        $this->generate_and_download_credit_note_pdf($order_id);
        exit;
    }

    public function generate_and_download_credit_note_pdf($order_id) {
        $order = wc_get_order($order_id);
        if (!$order) {
            return;
        }

        $custom_base_dir = WP_CONTENT_DIR . '/addify-pdf-invoices-and-packing-slip/credit-note';
        $default_base_dir = PDF_PLUGIN_DIR . 'includes/templates/credit-note';
        $default_design = 'credit_note_temp1.php';

        if (!file_exists($custom_base_dir) || !is_dir($custom_base_dir)) {
            $base_dir = $default_base_dir;
        } else {
            $base_dir = $custom_base_dir;
        }

        $af_credit_note_pdf_select_design = get_option('af_credit_note_pdf_select_design') ? get_option('af_credit_note_pdf_select_design') : $default_design;

        if (substr($af_credit_note_pdf_select_design, -4) !== '.php') {
            $af_credit_note_pdf_select_design .= '.php';
        }

        if (!file_exists($base_dir . '/' . $af_credit_note_pdf_select_design)) {
            if (file_exists($default_base_dir . '/' . $af_credit_note_pdf_select_design)) {
                $base_dir = $default_base_dir;
            } else {
                $af_credit_note_pdf_select_design = $default_design;
                $base_dir = $default_base_dir;
            }
        }

        ob_start();
        include $base_dir . '/' . $af_credit_note_pdf_select_design;
        $af_credit_note_pdf = ob_get_clean();

        $options = new Dompdf\Options();
        $options->set('isPhpEnabled', true);
        $options->set('isRemoteEnabled', true);
        $options->set('defaultPaperSize', 'letter');
        $options->set('isHtml5ParserEnabled', true);
        $dompdf = new Dompdf\Dompdf($options);
        $dompdf->loadHtml($af_credit_note_pdf);
        $dompdf->setPaper('A4', 'Portrait');
        $dompdf->render();
        $dompdf->stream('credit-note-' . $order_id . '.pdf', array("Attachment" => 1));
    }

    public function populate_pdf_download_column($order) {
        $order_status = $order->get_status();
        if ($order_status === 'refunded') {
            $download_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_credit_note_pdf&order_id=' . $order->get_id()), 'download_credit_note_pdf');
            echo '<a href="' . esc_url($download_url) . '">' . __('Download Credit Note', 'woocommerce') . '</a>';
        } else {
            $download_url = wp_nonce_url(admin_url('admin-ajax.php?action=download_invoice_pdf&order_id=' . $order->get_id()), 'download_invoice_pdf');
            echo '<a href="' . esc_url($download_url) . '">' . __('Download PDF Invoice', 'woocommerce') . '</a>';
        }
    }

    public function add_pdf_download_column($columns) {
        $new_columns = array();

        foreach ($columns as $key => $column) {
            $new_columns[$key] = $column;
            if ($key === 'order-actions') {
                $new_columns['pdf-download'] = __('Download PDF', 'woocommerce');
            }
        }

        return $new_columns;
    }

    public function af_pdf_invoices_front_assests()
    {
        wp_enqueue_style('af_mli_font_awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', false, '4.7.0', false);

    }








}

new Addify_P_D_F_I_Front();

